# Autoremove Attachments

Autoremove Attachments helps you keep your media library clean by deleting all media files attached to a post when that post is permanently removed from your database.

By default, WordPress doesn't remove child attachments leaving orphan files behind. Using this plugin you won't have to manually track and remove them.

## Frequently Asked Questions

##### Does it work with custom post types?

Yes, it does. It works with posts, pages and custom post types. All child attachments are removed when the parent post is deleted.

##### When are the attachments removed?

The files are removed when the parent post is permanently removed from your system. A soft delete that places your post in Trash will not trigger the removal of your attachments.

The purge happens when you empty your trash.

##### Can I control what attachments are removed?

Yes, you can. By default, all media files attached to a post, page or custom post type are removed automatically. If you need granular control you can use the filter `autoremove_attachments_post_types` to define for what post types the child attachments should be removed automatically.

Here is an example:

```php
function autoremove_attachments_custom_post_types() {
	$post_types = array(
		'page',
		'project',
		'product',
	);

	return $post_types;
}
add_filter( 'autoremove_attachments_post_types', 'autoremove_attachments_custom_post_types' );
```

##### Are there any restrictions on how I can use my attachments?

Unfortunately, yes! You need to make sure that you don't insert your files into multiple posts. If you do and the parent post is deleted you will end up with missing images.

If you need to use the same image over and over again, upload it from the Media Library ( Media > Add New ). This way the image won't be attached to any post and you will be able to use it without restrictions.
